# Header

A document header.

**Type:** object

## Properties

- **headerId** (string): The ID of the header.
- **content** (array of [StructuralElement](structuralelement.md)): The contents of the header. The indexes for a header's content begin at zero.
